"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class FieldCreateDocumentFieldsTypeDropdownRequest1(str, Enum):
    DROPDOWN = "DROPDOWN"


class FieldCreateDocumentFieldsTypeDropdownRequest2(str, Enum):
    DROPDOWN = "dropdown"


class FieldCreateDocumentFieldsValueDropdownTypedDict(TypedDict):
    value: str


class FieldCreateDocumentFieldsValueDropdown(BaseModel):
    value: str


class FieldCreateDocumentFieldsFieldMetaDropdownRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeDropdownRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueDropdownTypedDict]]
    default_value: NotRequired[str]


class FieldCreateDocumentFieldsFieldMetaDropdownRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeDropdownRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueDropdown]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldCreateDocumentFieldsFieldDropdownTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeDropdownRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaDropdownRequestTypedDict]


class FieldCreateDocumentFieldsFieldDropdown(BaseModel):
    type: FieldCreateDocumentFieldsTypeDropdownRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaDropdownRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeCheckboxRequest1(str, Enum):
    CHECKBOX = "CHECKBOX"


class FieldCreateDocumentFieldsTypeCheckboxRequest2(str, Enum):
    CHECKBOX = "checkbox"


class FieldCreateDocumentFieldsValueCheckboxTypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldCreateDocumentFieldsValueCheckbox(BaseModel):
    id: float

    checked: bool

    value: str


class FieldCreateDocumentFieldsDirectionCheckbox(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldCreateDocumentFieldsFieldMetaCheckboxRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeCheckboxRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueCheckboxTypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldCreateDocumentFieldsDirectionCheckbox]


class FieldCreateDocumentFieldsFieldMetaCheckboxRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeCheckboxRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueCheckbox]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldCreateDocumentFieldsDirectionCheckbox] = (
        FieldCreateDocumentFieldsDirectionCheckbox.VERTICAL
    )


class FieldCreateDocumentFieldsFieldCheckboxTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeCheckboxRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaCheckboxRequestTypedDict]


class FieldCreateDocumentFieldsFieldCheckbox(BaseModel):
    type: FieldCreateDocumentFieldsTypeCheckboxRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaCheckboxRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeRadioRequest1(str, Enum):
    RADIO = "RADIO"


class FieldCreateDocumentFieldsTypeRadioRequest2(str, Enum):
    RADIO = "radio"


class FieldCreateDocumentFieldsValueRadioTypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldCreateDocumentFieldsValueRadio(BaseModel):
    id: float

    checked: bool

    value: str


class FieldCreateDocumentFieldsDirectionRadio(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldCreateDocumentFieldsFieldMetaRadioRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeRadioRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueRadioTypedDict]]
    direction: NotRequired[FieldCreateDocumentFieldsDirectionRadio]


class FieldCreateDocumentFieldsFieldMetaRadioRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeRadioRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueRadio]] = None

    direction: Optional[FieldCreateDocumentFieldsDirectionRadio] = (
        FieldCreateDocumentFieldsDirectionRadio.VERTICAL
    )


class FieldCreateDocumentFieldsFieldRadioTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeRadioRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaRadioRequestTypedDict]


class FieldCreateDocumentFieldsFieldRadio(BaseModel):
    type: FieldCreateDocumentFieldsTypeRadioRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaRadioRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeNumberRequest1(str, Enum):
    NUMBER = "NUMBER"


class FieldCreateDocumentFieldsTypeNumberRequest2(str, Enum):
    NUMBER = "number"


class FieldCreateDocumentFieldsTextAlignNumber(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsVerticalAlignNumber(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldCreateDocumentFieldsFieldMetaNumberRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeNumberRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignNumber]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldCreateDocumentFieldsVerticalAlignNumber]]


class FieldCreateDocumentFieldsFieldMetaNumberRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeNumberRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignNumber],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldCreateDocumentFieldsVerticalAlignNumber],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldCreateDocumentFieldsFieldNumberTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeNumberRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaNumberRequestTypedDict]


class FieldCreateDocumentFieldsFieldNumber(BaseModel):
    type: FieldCreateDocumentFieldsTypeNumberRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaNumberRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeTextRequest1(str, Enum):
    TEXT = "TEXT"


class FieldCreateDocumentFieldsTypeTextRequest2(str, Enum):
    TEXT = "text"


class FieldCreateDocumentFieldsTextAlignText(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsVerticalAlignText(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldCreateDocumentFieldsFieldMetaTextRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeTextRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignText]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldCreateDocumentFieldsVerticalAlignText]]


class FieldCreateDocumentFieldsFieldMetaTextRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeTextRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignText],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldCreateDocumentFieldsVerticalAlignText],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldCreateDocumentFieldsFieldTextTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeTextRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaTextRequestTypedDict]


class FieldCreateDocumentFieldsFieldText(BaseModel):
    type: FieldCreateDocumentFieldsTypeTextRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaTextRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeDateRequest1(str, Enum):
    DATE = "DATE"


class FieldCreateDocumentFieldsTypeDateRequest2(str, Enum):
    DATE = "date"


class FieldCreateDocumentFieldsTextAlignDate(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaDateRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeDateRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignDate]


class FieldCreateDocumentFieldsFieldMetaDateRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeDateRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignDate],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldDateTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeDateRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaDateRequestTypedDict]


class FieldCreateDocumentFieldsFieldDate(BaseModel):
    type: FieldCreateDocumentFieldsTypeDateRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaDateRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeEmailRequest1(str, Enum):
    EMAIL = "EMAIL"


class FieldCreateDocumentFieldsTypeEmailRequest2(str, Enum):
    EMAIL = "email"


class FieldCreateDocumentFieldsTextAlignEmail(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaEmailRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeEmailRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignEmail]


class FieldCreateDocumentFieldsFieldMetaEmailRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeEmailRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignEmail],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldEmailTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeEmailRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaEmailRequestTypedDict]


class FieldCreateDocumentFieldsFieldEmail(BaseModel):
    type: FieldCreateDocumentFieldsTypeEmailRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaEmailRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeNameRequest1(str, Enum):
    NAME = "NAME"


class FieldCreateDocumentFieldsTypeNameRequest2(str, Enum):
    NAME = "name"


class FieldCreateDocumentFieldsTextAlignName(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaNameRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeNameRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignName]


class FieldCreateDocumentFieldsFieldMetaNameRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeNameRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignName],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldNameTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeNameRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaNameRequestTypedDict]


class FieldCreateDocumentFieldsFieldName(BaseModel):
    type: FieldCreateDocumentFieldsTypeNameRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaNameRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeInitialsRequest1(str, Enum):
    INITIALS = "INITIALS"


class FieldCreateDocumentFieldsTypeInitialsRequest2(str, Enum):
    INITIALS = "initials"


class FieldCreateDocumentFieldsTextAlignInitials(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaInitialsRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeInitialsRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignInitials]


class FieldCreateDocumentFieldsFieldMetaInitialsRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeInitialsRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignInitials],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldInitialsTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeInitialsRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaInitialsRequestTypedDict]


class FieldCreateDocumentFieldsFieldInitials(BaseModel):
    type: FieldCreateDocumentFieldsTypeInitialsRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaInitialsRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


class FieldCreateDocumentFieldsTypeFreeSignature(str, Enum):
    FREE_SIGNATURE = "FREE_SIGNATURE"


class FieldCreateDocumentFieldsFieldFreeSignatureTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeFreeSignature
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float


class FieldCreateDocumentFieldsFieldFreeSignature(BaseModel):
    type: FieldCreateDocumentFieldsTypeFreeSignature

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float


class FieldCreateDocumentFieldsTypeSignatureRequest1(str, Enum):
    SIGNATURE = "SIGNATURE"


class FieldCreateDocumentFieldsTypeSignatureRequest2(str, Enum):
    SIGNATURE = "signature"


class FieldCreateDocumentFieldsFieldMetaSignatureRequestTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeSignatureRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldCreateDocumentFieldsFieldMetaSignatureRequest(BaseModel):
    type: FieldCreateDocumentFieldsTypeSignatureRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


class FieldCreateDocumentFieldsFieldSignatureTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsTypeSignatureRequest1
    recipient_id: float
    page_number: float
    page_x: float
    page_y: float
    width: float
    height: float
    field_meta: NotRequired[FieldCreateDocumentFieldsFieldMetaSignatureRequestTypedDict]


class FieldCreateDocumentFieldsFieldSignature(BaseModel):
    type: FieldCreateDocumentFieldsTypeSignatureRequest1

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page_number: Annotated[float, pydantic.Field(alias="pageNumber")]

    page_x: Annotated[float, pydantic.Field(alias="pageX")]

    page_y: Annotated[float, pydantic.Field(alias="pageY")]

    width: float

    height: float

    field_meta: Annotated[
        Optional[FieldCreateDocumentFieldsFieldMetaSignatureRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None


FieldCreateDocumentFieldsFieldUnionTypedDict = TypeAliasType(
    "FieldCreateDocumentFieldsFieldUnionTypedDict",
    Union[
        FieldCreateDocumentFieldsFieldFreeSignatureTypedDict,
        FieldCreateDocumentFieldsFieldSignatureTypedDict,
        FieldCreateDocumentFieldsFieldInitialsTypedDict,
        FieldCreateDocumentFieldsFieldNameTypedDict,
        FieldCreateDocumentFieldsFieldEmailTypedDict,
        FieldCreateDocumentFieldsFieldDateTypedDict,
        FieldCreateDocumentFieldsFieldTextTypedDict,
        FieldCreateDocumentFieldsFieldNumberTypedDict,
        FieldCreateDocumentFieldsFieldRadioTypedDict,
        FieldCreateDocumentFieldsFieldCheckboxTypedDict,
        FieldCreateDocumentFieldsFieldDropdownTypedDict,
    ],
)


FieldCreateDocumentFieldsFieldUnion = TypeAliasType(
    "FieldCreateDocumentFieldsFieldUnion",
    Union[
        FieldCreateDocumentFieldsFieldFreeSignature,
        FieldCreateDocumentFieldsFieldSignature,
        FieldCreateDocumentFieldsFieldInitials,
        FieldCreateDocumentFieldsFieldName,
        FieldCreateDocumentFieldsFieldEmail,
        FieldCreateDocumentFieldsFieldDate,
        FieldCreateDocumentFieldsFieldText,
        FieldCreateDocumentFieldsFieldNumber,
        FieldCreateDocumentFieldsFieldRadio,
        FieldCreateDocumentFieldsFieldCheckbox,
        FieldCreateDocumentFieldsFieldDropdown,
    ],
)


class FieldCreateDocumentFieldsRequestTypedDict(TypedDict):
    document_id: float
    fields: List[FieldCreateDocumentFieldsFieldUnionTypedDict]


class FieldCreateDocumentFieldsRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]

    fields: List[FieldCreateDocumentFieldsFieldUnion]


class FieldCreateDocumentFieldsInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FieldCreateDocumentFieldsInternalServerErrorIssue(BaseModel):
    message: str


class FieldCreateDocumentFieldsInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldCreateDocumentFieldsInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FieldCreateDocumentFieldsInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FieldCreateDocumentFieldsInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldCreateDocumentFieldsInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldCreateDocumentFieldsForbiddenIssueTypedDict(TypedDict):
    message: str


class FieldCreateDocumentFieldsForbiddenIssue(BaseModel):
    message: str


class FieldCreateDocumentFieldsForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldCreateDocumentFieldsForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FieldCreateDocumentFieldsForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FieldCreateDocumentFieldsForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldCreateDocumentFieldsForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldCreateDocumentFieldsUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FieldCreateDocumentFieldsUnauthorizedIssue(BaseModel):
    message: str


class FieldCreateDocumentFieldsUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldCreateDocumentFieldsUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FieldCreateDocumentFieldsUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FieldCreateDocumentFieldsUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldCreateDocumentFieldsUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldCreateDocumentFieldsBadRequestIssueTypedDict(TypedDict):
    message: str


class FieldCreateDocumentFieldsBadRequestIssue(BaseModel):
    message: str


class FieldCreateDocumentFieldsBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldCreateDocumentFieldsBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FieldCreateDocumentFieldsBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FieldCreateDocumentFieldsBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldCreateDocumentFieldsBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldCreateDocumentFieldsTypeResponse(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class FieldCreateDocumentFieldsFieldMetaTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class FieldCreateDocumentFieldsValueResponse3TypedDict(TypedDict):
    value: str


class FieldCreateDocumentFieldsValueResponse3(BaseModel):
    value: str


class FieldCreateDocumentFieldsFieldMetaDropdownResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueResponse3TypedDict]]
    default_value: NotRequired[str]


class FieldCreateDocumentFieldsFieldMetaDropdownResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueResponse3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldCreateDocumentFieldsFieldMetaTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class FieldCreateDocumentFieldsValueResponse2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldCreateDocumentFieldsValueResponse2(BaseModel):
    id: float

    checked: bool

    value: str


class FieldCreateDocumentFieldsDirectionResponse2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldCreateDocumentFieldsFieldMetaCheckboxResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueResponse2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldCreateDocumentFieldsDirectionResponse2]


class FieldCreateDocumentFieldsFieldMetaCheckboxResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueResponse2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldCreateDocumentFieldsDirectionResponse2] = (
        FieldCreateDocumentFieldsDirectionResponse2.VERTICAL
    )


class FieldCreateDocumentFieldsFieldMetaTypeRadio(str, Enum):
    RADIO = "radio"


class FieldCreateDocumentFieldsValueResponse1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldCreateDocumentFieldsValueResponse1(BaseModel):
    id: float

    checked: bool

    value: str


class FieldCreateDocumentFieldsDirectionResponse1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldCreateDocumentFieldsFieldMetaRadioResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldCreateDocumentFieldsValueResponse1TypedDict]]
    direction: NotRequired[FieldCreateDocumentFieldsDirectionResponse1]


class FieldCreateDocumentFieldsFieldMetaRadioResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldCreateDocumentFieldsValueResponse1]] = None

    direction: Optional[FieldCreateDocumentFieldsDirectionResponse1] = (
        FieldCreateDocumentFieldsDirectionResponse1.VERTICAL
    )


class FieldCreateDocumentFieldsFieldMetaTypeNumber(str, Enum):
    NUMBER = "number"


class FieldCreateDocumentFieldsTextAlignResponse6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsVerticalAlignResponse2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldCreateDocumentFieldsFieldMetaNumberResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[FieldCreateDocumentFieldsVerticalAlignResponse2]
    ]


class FieldCreateDocumentFieldsFieldMetaNumberResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse6],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldCreateDocumentFieldsVerticalAlignResponse2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldCreateDocumentFieldsFieldMetaTypeText(str, Enum):
    TEXT = "text"


class FieldCreateDocumentFieldsTextAlignResponse5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsVerticalAlignResponse1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldCreateDocumentFieldsFieldMetaTextResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[FieldCreateDocumentFieldsVerticalAlignResponse1]
    ]


class FieldCreateDocumentFieldsFieldMetaTextResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse5],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldCreateDocumentFieldsVerticalAlignResponse1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldCreateDocumentFieldsFieldMetaTypeDate(str, Enum):
    DATE = "date"


class FieldCreateDocumentFieldsTextAlignResponse4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaDateResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse4]


class FieldCreateDocumentFieldsFieldMetaDateResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse4],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldMetaTypeEmail(str, Enum):
    EMAIL = "email"


class FieldCreateDocumentFieldsTextAlignResponse3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaEmailResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse3]


class FieldCreateDocumentFieldsFieldMetaEmailResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse3],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldMetaTypeName(str, Enum):
    NAME = "name"


class FieldCreateDocumentFieldsTextAlignResponse2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaNameResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse2]


class FieldCreateDocumentFieldsFieldMetaNameResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse2],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldMetaTypeInitials(str, Enum):
    INITIALS = "initials"


class FieldCreateDocumentFieldsTextAlignResponse1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldCreateDocumentFieldsFieldMetaInitialsResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldCreateDocumentFieldsTextAlignResponse1]


class FieldCreateDocumentFieldsFieldMetaInitialsResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldCreateDocumentFieldsTextAlignResponse1],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldCreateDocumentFieldsFieldMetaTypeSignature(str, Enum):
    SIGNATURE = "signature"


class FieldCreateDocumentFieldsFieldMetaSignatureResponseTypedDict(TypedDict):
    type: FieldCreateDocumentFieldsFieldMetaTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldCreateDocumentFieldsFieldMetaSignatureResponse(BaseModel):
    type: FieldCreateDocumentFieldsFieldMetaTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


FieldCreateDocumentFieldsFieldMetaUnionTypedDict = TypeAliasType(
    "FieldCreateDocumentFieldsFieldMetaUnionTypedDict",
    Union[
        FieldCreateDocumentFieldsFieldMetaSignatureResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaInitialsResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaNameResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaEmailResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaDateResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaRadioResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaDropdownResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaCheckboxResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaTextResponseTypedDict,
        FieldCreateDocumentFieldsFieldMetaNumberResponseTypedDict,
    ],
)


FieldCreateDocumentFieldsFieldMetaUnion = TypeAliasType(
    "FieldCreateDocumentFieldsFieldMetaUnion",
    Union[
        FieldCreateDocumentFieldsFieldMetaSignatureResponse,
        FieldCreateDocumentFieldsFieldMetaInitialsResponse,
        FieldCreateDocumentFieldsFieldMetaNameResponse,
        FieldCreateDocumentFieldsFieldMetaEmailResponse,
        FieldCreateDocumentFieldsFieldMetaDateResponse,
        FieldCreateDocumentFieldsFieldMetaRadioResponse,
        FieldCreateDocumentFieldsFieldMetaDropdownResponse,
        FieldCreateDocumentFieldsFieldMetaCheckboxResponse,
        FieldCreateDocumentFieldsFieldMetaTextResponse,
        FieldCreateDocumentFieldsFieldMetaNumberResponse,
    ],
)


class FieldCreateDocumentFieldsFieldResponseTypedDict(TypedDict):
    envelope_id: str
    envelope_item_id: str
    type: FieldCreateDocumentFieldsTypeResponse
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[FieldCreateDocumentFieldsFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class FieldCreateDocumentFieldsFieldResponse(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: FieldCreateDocumentFieldsTypeResponse

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[FieldCreateDocumentFieldsFieldMetaUnion],
        pydantic.Field(alias="fieldMeta"),
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldCreateDocumentFieldsResponseTypedDict(TypedDict):
    r"""Successful response"""

    fields: List[FieldCreateDocumentFieldsFieldResponseTypedDict]


class FieldCreateDocumentFieldsResponse(BaseModel):
    r"""Successful response"""

    fields: List[FieldCreateDocumentFieldsFieldResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class EnvelopeUpdateDataVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class EnvelopeUpdateDataGlobalAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class EnvelopeUpdateDataGlobalActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"


class EnvelopeUpdateDataTypedDict(TypedDict):
    title: NotRequired[str]
    external_id: NotRequired[Nullable[str]]
    visibility: NotRequired[EnvelopeUpdateDataVisibility]
    global_access_auth: NotRequired[List[EnvelopeUpdateDataGlobalAccessAuth]]
    global_action_auth: NotRequired[List[EnvelopeUpdateDataGlobalActionAuth]]
    folder_id: NotRequired[Nullable[str]]


class EnvelopeUpdateData(BaseModel):
    title: Optional[str] = None

    external_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="externalId")
    ] = UNSET

    visibility: Optional[EnvelopeUpdateDataVisibility] = None

    global_access_auth: Annotated[
        Optional[List[EnvelopeUpdateDataGlobalAccessAuth]],
        pydantic.Field(alias="globalAccessAuth"),
    ] = None

    global_action_auth: Annotated[
        Optional[List[EnvelopeUpdateDataGlobalActionAuth]],
        pydantic.Field(alias="globalActionAuth"),
    ] = None

    folder_id: Annotated[OptionalNullable[str], pydantic.Field(alias="folderId")] = (
        UNSET
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "title",
            "externalId",
            "visibility",
            "globalAccessAuth",
            "globalActionAuth",
            "folderId",
        ]
        nullable_fields = ["externalId", "folderId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class EnvelopeUpdateDateFormat(str, Enum):
    YYYY_M_MDD_HH_MM_A = "yyyy-MM-dd hh:mm a"
    YYYY_M_MDD = "yyyy-MM-dd"
    DD_MM_SLASH_YYYY = "dd/MM/yyyy"
    MM_DD_SLASH_YYYY = "MM/dd/yyyy"
    YY_M_MDD = "yy-MM-dd"
    MMMM_DD_COMMA_YYYY = "MMMM dd, yyyy"
    EEEE_MMMM_DD_COMMA_YYYY = "EEEE, MMMM dd, yyyy"
    DD_MM_SLASH_YYYY_HH_MM_A = "dd/MM/yyyy hh:mm a"
    DD_MM_SLASH_YYYY_H_HMM = "dd/MM/yyyy HH:mm"
    MM_DD_SLASH_YYYY_HH_MM_A = "MM/dd/yyyy hh:mm a"
    MM_DD_SLASH_YYYY_H_HMM = "MM/dd/yyyy HH:mm"
    DD_DOT_MM_DOT_YYYY = "dd.MM.yyyy"
    DD_DOT_MM_DOT_YYYY_H_HMM = "dd.MM.yyyy HH:mm"
    YYYY_M_MDD_H_HMM = "yyyy-MM-dd HH:mm"
    YY_M_MDD_HH_MM_A = "yy-MM-dd hh:mm a"
    YY_M_MDD_H_HMM = "yy-MM-dd HH:mm"
    YYYY_M_MDD_H_HMMSS = "yyyy-MM-dd HH:mm:ss"
    MMMM_DD_COMMA_YYYY_HH_MM_A = "MMMM dd, yyyy hh:mm a"
    MMMM_DD_COMMA_YYYY_H_HMM = "MMMM dd, yyyy HH:mm"
    EEEE_MMMM_DD_COMMA_YYYY_HH_MM_A = "EEEE, MMMM dd, yyyy hh:mm a"
    EEEE_MMMM_DD_COMMA_YYYY_H_HMM = "EEEE, MMMM dd, yyyy HH:mm"
    ISO8601_FULL = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX"


class EnvelopeUpdateDistributionMethod(str, Enum):
    EMAIL = "EMAIL"
    NONE = "NONE"


class EnvelopeUpdateSigningOrder(str, Enum):
    PARALLEL = "PARALLEL"
    SEQUENTIAL = "SEQUENTIAL"


class EnvelopeUpdateLanguage(str, Enum):
    DE = "de"
    EN = "en"
    FR = "fr"
    ES = "es"
    IT = "it"
    PL = "pl"


class EnvelopeUpdateEmailSettingsTypedDict(TypedDict):
    recipient_signing_request: NotRequired[bool]
    recipient_removed: NotRequired[bool]
    recipient_signed: NotRequired[bool]
    document_pending: NotRequired[bool]
    document_completed: NotRequired[bool]
    document_deleted: NotRequired[bool]
    owner_document_completed: NotRequired[bool]


class EnvelopeUpdateEmailSettings(BaseModel):
    recipient_signing_request: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigningRequest")
    ] = True

    recipient_removed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientRemoved")
    ] = True

    recipient_signed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigned")
    ] = True

    document_pending: Annotated[
        Optional[bool], pydantic.Field(alias="documentPending")
    ] = True

    document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="documentCompleted")
    ] = True

    document_deleted: Annotated[
        Optional[bool], pydantic.Field(alias="documentDeleted")
    ] = True

    owner_document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="ownerDocumentCompleted")
    ] = True


class EnvelopeUpdateMetaTypedDict(TypedDict):
    subject: NotRequired[str]
    message: NotRequired[str]
    timezone: NotRequired[str]
    date_format: NotRequired[EnvelopeUpdateDateFormat]
    distribution_method: NotRequired[EnvelopeUpdateDistributionMethod]
    signing_order: NotRequired[EnvelopeUpdateSigningOrder]
    allow_dictate_next_signer: NotRequired[bool]
    redirect_url: NotRequired[str]
    language: NotRequired[EnvelopeUpdateLanguage]
    typed_signature_enabled: NotRequired[bool]
    upload_signature_enabled: NotRequired[bool]
    draw_signature_enabled: NotRequired[bool]
    email_id: NotRequired[Nullable[str]]
    email_reply_to: NotRequired[Nullable[str]]
    email_settings: NotRequired[Nullable[EnvelopeUpdateEmailSettingsTypedDict]]


class EnvelopeUpdateMeta(BaseModel):
    subject: Optional[str] = None

    message: Optional[str] = None

    timezone: Optional[str] = None

    date_format: Annotated[
        Optional[EnvelopeUpdateDateFormat], pydantic.Field(alias="dateFormat")
    ] = None

    distribution_method: Annotated[
        Optional[EnvelopeUpdateDistributionMethod],
        pydantic.Field(alias="distributionMethod"),
    ] = None

    signing_order: Annotated[
        Optional[EnvelopeUpdateSigningOrder], pydantic.Field(alias="signingOrder")
    ] = None

    allow_dictate_next_signer: Annotated[
        Optional[bool], pydantic.Field(alias="allowDictateNextSigner")
    ] = None

    redirect_url: Annotated[Optional[str], pydantic.Field(alias="redirectUrl")] = None

    language: Optional[EnvelopeUpdateLanguage] = None

    typed_signature_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="typedSignatureEnabled")
    ] = None

    upload_signature_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="uploadSignatureEnabled")
    ] = None

    draw_signature_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="drawSignatureEnabled")
    ] = None

    email_id: Annotated[OptionalNullable[str], pydantic.Field(alias="emailId")] = UNSET

    email_reply_to: Annotated[
        OptionalNullable[str], pydantic.Field(alias="emailReplyTo")
    ] = UNSET

    email_settings: Annotated[
        OptionalNullable[EnvelopeUpdateEmailSettings],
        pydantic.Field(alias="emailSettings"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "subject",
            "message",
            "timezone",
            "dateFormat",
            "distributionMethod",
            "signingOrder",
            "allowDictateNextSigner",
            "redirectUrl",
            "language",
            "typedSignatureEnabled",
            "uploadSignatureEnabled",
            "drawSignatureEnabled",
            "emailId",
            "emailReplyTo",
            "emailSettings",
        ]
        nullable_fields = ["emailId", "emailReplyTo", "emailSettings"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class EnvelopeUpdateRequestTypedDict(TypedDict):
    envelope_id: str
    data: NotRequired[EnvelopeUpdateDataTypedDict]
    meta: NotRequired[EnvelopeUpdateMetaTypedDict]


class EnvelopeUpdateRequest(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    data: Optional[EnvelopeUpdateData] = None

    meta: Optional[EnvelopeUpdateMeta] = None


class EnvelopeUpdateInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class EnvelopeUpdateInternalServerErrorIssue(BaseModel):
    message: str


class EnvelopeUpdateInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeUpdateInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeUpdateInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EnvelopeUpdateInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeUpdateInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeUpdateForbiddenIssueTypedDict(TypedDict):
    message: str


class EnvelopeUpdateForbiddenIssue(BaseModel):
    message: str


class EnvelopeUpdateForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeUpdateForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeUpdateForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EnvelopeUpdateForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeUpdateForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeUpdateUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EnvelopeUpdateUnauthorizedIssue(BaseModel):
    message: str


class EnvelopeUpdateUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeUpdateUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeUpdateUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EnvelopeUpdateUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeUpdateUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeUpdateBadRequestIssueTypedDict(TypedDict):
    message: str


class EnvelopeUpdateBadRequestIssue(BaseModel):
    message: str


class EnvelopeUpdateBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeUpdateBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeUpdateBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EnvelopeUpdateBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeUpdateBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeUpdateType(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"


class EnvelopeUpdateStatus(str, Enum):
    DRAFT = "DRAFT"
    PENDING = "PENDING"
    COMPLETED = "COMPLETED"
    REJECTED = "REJECTED"


class EnvelopeUpdateSource(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"
    TEMPLATE_DIRECT_LINK = "TEMPLATE_DIRECT_LINK"


class EnvelopeUpdateVisibilityResponse(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class EnvelopeUpdateTemplateType(str, Enum):
    PUBLIC = "PUBLIC"
    PRIVATE = "PRIVATE"


class EnvelopeUpdateGlobalAccessAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class EnvelopeUpdateGlobalActionAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"


class EnvelopeUpdateAuthOptionsTypedDict(TypedDict):
    global_access_auth: List[EnvelopeUpdateGlobalAccessAuthResponse]
    global_action_auth: List[EnvelopeUpdateGlobalActionAuthResponse]


class EnvelopeUpdateAuthOptions(BaseModel):
    global_access_auth: Annotated[
        List[EnvelopeUpdateGlobalAccessAuthResponse],
        pydantic.Field(alias="globalAccessAuth"),
    ]

    global_action_auth: Annotated[
        List[EnvelopeUpdateGlobalActionAuthResponse],
        pydantic.Field(alias="globalActionAuth"),
    ]


EnvelopeUpdateFormValuesTypedDict = TypeAliasType(
    "EnvelopeUpdateFormValuesTypedDict", Union[str, bool, float]
)


EnvelopeUpdateFormValues = TypeAliasType(
    "EnvelopeUpdateFormValues", Union[str, bool, float]
)


class EnvelopeUpdateResponseTypedDict(TypedDict):
    r"""Successful response"""

    internal_version: float
    type: EnvelopeUpdateType
    status: EnvelopeUpdateStatus
    source: EnvelopeUpdateSource
    visibility: EnvelopeUpdateVisibilityResponse
    template_type: EnvelopeUpdateTemplateType
    id: str
    secondary_id: str
    external_id: Nullable[str]
    created_at: str
    updated_at: str
    completed_at: Nullable[str]
    deleted_at: Nullable[str]
    title: str
    auth_options: Nullable[EnvelopeUpdateAuthOptionsTypedDict]
    form_values: Nullable[Dict[str, EnvelopeUpdateFormValuesTypedDict]]
    public_title: str
    public_description: str
    user_id: float
    team_id: float
    folder_id: Nullable[str]


class EnvelopeUpdateResponse(BaseModel):
    r"""Successful response"""

    internal_version: Annotated[float, pydantic.Field(alias="internalVersion")]

    type: EnvelopeUpdateType

    status: EnvelopeUpdateStatus

    source: EnvelopeUpdateSource

    visibility: EnvelopeUpdateVisibilityResponse

    template_type: Annotated[
        EnvelopeUpdateTemplateType, pydantic.Field(alias="templateType")
    ]

    id: str

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    external_id: Annotated[Nullable[str], pydantic.Field(alias="externalId")]

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    completed_at: Annotated[Nullable[str], pydantic.Field(alias="completedAt")]

    deleted_at: Annotated[Nullable[str], pydantic.Field(alias="deletedAt")]

    title: str

    auth_options: Annotated[
        Nullable[EnvelopeUpdateAuthOptions], pydantic.Field(alias="authOptions")
    ]

    form_values: Annotated[
        Nullable[Dict[str, EnvelopeUpdateFormValues]],
        pydantic.Field(alias="formValues"),
    ]

    public_title: Annotated[str, pydantic.Field(alias="publicTitle")]

    public_description: Annotated[str, pydantic.Field(alias="publicDescription")]

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    folder_id: Annotated[Nullable[str], pydantic.Field(alias="folderId")]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "externalId",
            "completedAt",
            "deletedAt",
            "authOptions",
            "formValues",
            "folderId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class RecipientUpdateTemplateRecipientsRoleRequest(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientUpdateTemplateRecipientsAccessAuthRequest(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientUpdateTemplateRecipientsActionAuthRequest(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientUpdateTemplateRecipientsRecipientRequestTypedDict(TypedDict):
    id: float
    email: NotRequired[str]
    name: NotRequired[str]
    role: NotRequired[RecipientUpdateTemplateRecipientsRoleRequest]
    signing_order: NotRequired[float]
    access_auth: NotRequired[List[RecipientUpdateTemplateRecipientsAccessAuthRequest]]
    action_auth: NotRequired[List[RecipientUpdateTemplateRecipientsActionAuthRequest]]


class RecipientUpdateTemplateRecipientsRecipientRequest(BaseModel):
    id: float

    email: Optional[str] = None

    name: Optional[str] = None

    role: Optional[RecipientUpdateTemplateRecipientsRoleRequest] = None

    signing_order: Annotated[Optional[float], pydantic.Field(alias="signingOrder")] = (
        None
    )

    access_auth: Annotated[
        Optional[List[RecipientUpdateTemplateRecipientsAccessAuthRequest]],
        pydantic.Field(alias="accessAuth"),
    ] = None

    action_auth: Annotated[
        Optional[List[RecipientUpdateTemplateRecipientsActionAuthRequest]],
        pydantic.Field(alias="actionAuth"),
    ] = None


class RecipientUpdateTemplateRecipientsRequestTypedDict(TypedDict):
    template_id: float
    recipients: List[RecipientUpdateTemplateRecipientsRecipientRequestTypedDict]


class RecipientUpdateTemplateRecipientsRequest(BaseModel):
    template_id: Annotated[float, pydantic.Field(alias="templateId")]

    recipients: List[RecipientUpdateTemplateRecipientsRecipientRequest]


class RecipientUpdateTemplateRecipientsInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class RecipientUpdateTemplateRecipientsInternalServerErrorIssue(BaseModel):
    message: str


class RecipientUpdateTemplateRecipientsInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[
        List[RecipientUpdateTemplateRecipientsInternalServerErrorIssue]
    ] = None


@dataclass(unsafe_hash=True)
class RecipientUpdateTemplateRecipientsInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: RecipientUpdateTemplateRecipientsInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientUpdateTemplateRecipientsInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientUpdateTemplateRecipientsForbiddenIssueTypedDict(TypedDict):
    message: str


class RecipientUpdateTemplateRecipientsForbiddenIssue(BaseModel):
    message: str


class RecipientUpdateTemplateRecipientsForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientUpdateTemplateRecipientsForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientUpdateTemplateRecipientsForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: RecipientUpdateTemplateRecipientsForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientUpdateTemplateRecipientsForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientUpdateTemplateRecipientsUnauthorizedIssueTypedDict(TypedDict):
    message: str


class RecipientUpdateTemplateRecipientsUnauthorizedIssue(BaseModel):
    message: str


class RecipientUpdateTemplateRecipientsUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientUpdateTemplateRecipientsUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientUpdateTemplateRecipientsUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: RecipientUpdateTemplateRecipientsUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientUpdateTemplateRecipientsUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientUpdateTemplateRecipientsBadRequestIssueTypedDict(TypedDict):
    message: str


class RecipientUpdateTemplateRecipientsBadRequestIssue(BaseModel):
    message: str


class RecipientUpdateTemplateRecipientsBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientUpdateTemplateRecipientsBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientUpdateTemplateRecipientsBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: RecipientUpdateTemplateRecipientsBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientUpdateTemplateRecipientsBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientUpdateTemplateRecipientsRoleResponse(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientUpdateTemplateRecipientsReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class RecipientUpdateTemplateRecipientsSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class RecipientUpdateTemplateRecipientsSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class RecipientUpdateTemplateRecipientsAccessAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientUpdateTemplateRecipientsActionAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientUpdateTemplateRecipientsAuthOptionsTypedDict(TypedDict):
    access_auth: List[RecipientUpdateTemplateRecipientsAccessAuthResponse]
    action_auth: List[RecipientUpdateTemplateRecipientsActionAuthResponse]


class RecipientUpdateTemplateRecipientsAuthOptions(BaseModel):
    access_auth: Annotated[
        List[RecipientUpdateTemplateRecipientsAccessAuthResponse],
        pydantic.Field(alias="accessAuth"),
    ]

    action_auth: Annotated[
        List[RecipientUpdateTemplateRecipientsActionAuthResponse],
        pydantic.Field(alias="actionAuth"),
    ]


class RecipientUpdateTemplateRecipientsType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class RecipientUpdateTemplateRecipientsTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class RecipientUpdateTemplateRecipientsValue3TypedDict(TypedDict):
    value: str


class RecipientUpdateTemplateRecipientsValue3(BaseModel):
    value: str


class RecipientUpdateTemplateRecipientsFieldMetaDropdownTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientUpdateTemplateRecipientsValue3TypedDict]]
    default_value: NotRequired[str]


class RecipientUpdateTemplateRecipientsFieldMetaDropdown(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientUpdateTemplateRecipientsValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class RecipientUpdateTemplateRecipientsTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class RecipientUpdateTemplateRecipientsValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientUpdateTemplateRecipientsValue2(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientUpdateTemplateRecipientsDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientUpdateTemplateRecipientsFieldMetaCheckboxTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientUpdateTemplateRecipientsValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[RecipientUpdateTemplateRecipientsDirection2]


class RecipientUpdateTemplateRecipientsFieldMetaCheckbox(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientUpdateTemplateRecipientsValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[RecipientUpdateTemplateRecipientsDirection2] = (
        RecipientUpdateTemplateRecipientsDirection2.VERTICAL
    )


class RecipientUpdateTemplateRecipientsTypeRadio(str, Enum):
    RADIO = "radio"


class RecipientUpdateTemplateRecipientsValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientUpdateTemplateRecipientsValue1(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientUpdateTemplateRecipientsDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientUpdateTemplateRecipientsFieldMetaRadioTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientUpdateTemplateRecipientsValue1TypedDict]]
    direction: NotRequired[RecipientUpdateTemplateRecipientsDirection1]


class RecipientUpdateTemplateRecipientsFieldMetaRadio(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientUpdateTemplateRecipientsValue1]] = None

    direction: Optional[RecipientUpdateTemplateRecipientsDirection1] = (
        RecipientUpdateTemplateRecipientsDirection1.VERTICAL
    )


class RecipientUpdateTemplateRecipientsTypeNumber(str, Enum):
    NUMBER = "number"


class RecipientUpdateTemplateRecipientsTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientUpdateTemplateRecipientsFieldMetaNumberTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[RecipientUpdateTemplateRecipientsVerticalAlign2]
    ]


class RecipientUpdateTemplateRecipientsFieldMetaNumber(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign6],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientUpdateTemplateRecipientsVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientUpdateTemplateRecipientsTypeText(str, Enum):
    TEXT = "text"


class RecipientUpdateTemplateRecipientsTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientUpdateTemplateRecipientsFieldMetaTextTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[RecipientUpdateTemplateRecipientsVerticalAlign1]
    ]


class RecipientUpdateTemplateRecipientsFieldMetaText(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign5],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientUpdateTemplateRecipientsVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientUpdateTemplateRecipientsTypeDate(str, Enum):
    DATE = "date"


class RecipientUpdateTemplateRecipientsTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsFieldMetaDateTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign4]


class RecipientUpdateTemplateRecipientsFieldMetaDate(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign4],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientUpdateTemplateRecipientsTypeEmail(str, Enum):
    EMAIL = "email"


class RecipientUpdateTemplateRecipientsTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsFieldMetaEmailTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign3]


class RecipientUpdateTemplateRecipientsFieldMetaEmail(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign3],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientUpdateTemplateRecipientsTypeName(str, Enum):
    NAME = "name"


class RecipientUpdateTemplateRecipientsTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsFieldMetaNameTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign2]


class RecipientUpdateTemplateRecipientsFieldMetaName(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign2],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientUpdateTemplateRecipientsTypeInitials(str, Enum):
    INITIALS = "initials"


class RecipientUpdateTemplateRecipientsTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientUpdateTemplateRecipientsFieldMetaInitialsTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientUpdateTemplateRecipientsTextAlign1]


class RecipientUpdateTemplateRecipientsFieldMetaInitials(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientUpdateTemplateRecipientsTextAlign1],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientUpdateTemplateRecipientsTypeSignature(str, Enum):
    SIGNATURE = "signature"


class RecipientUpdateTemplateRecipientsFieldMetaSignatureTypedDict(TypedDict):
    type: RecipientUpdateTemplateRecipientsTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class RecipientUpdateTemplateRecipientsFieldMetaSignature(BaseModel):
    type: RecipientUpdateTemplateRecipientsTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


RecipientUpdateTemplateRecipientsFieldMetaUnionTypedDict = TypeAliasType(
    "RecipientUpdateTemplateRecipientsFieldMetaUnionTypedDict",
    Union[
        RecipientUpdateTemplateRecipientsFieldMetaSignatureTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaInitialsTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaNameTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaEmailTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaDateTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaRadioTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaDropdownTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaCheckboxTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaTextTypedDict,
        RecipientUpdateTemplateRecipientsFieldMetaNumberTypedDict,
    ],
)


RecipientUpdateTemplateRecipientsFieldMetaUnion = TypeAliasType(
    "RecipientUpdateTemplateRecipientsFieldMetaUnion",
    Union[
        RecipientUpdateTemplateRecipientsFieldMetaSignature,
        RecipientUpdateTemplateRecipientsFieldMetaInitials,
        RecipientUpdateTemplateRecipientsFieldMetaName,
        RecipientUpdateTemplateRecipientsFieldMetaEmail,
        RecipientUpdateTemplateRecipientsFieldMetaDate,
        RecipientUpdateTemplateRecipientsFieldMetaRadio,
        RecipientUpdateTemplateRecipientsFieldMetaDropdown,
        RecipientUpdateTemplateRecipientsFieldMetaCheckbox,
        RecipientUpdateTemplateRecipientsFieldMetaText,
        RecipientUpdateTemplateRecipientsFieldMetaNumber,
    ],
)


class RecipientUpdateTemplateRecipientsFieldTypedDict(TypedDict):
    envelope_id: str
    envelope_item_id: str
    type: RecipientUpdateTemplateRecipientsType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[RecipientUpdateTemplateRecipientsFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientUpdateTemplateRecipientsField(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: RecipientUpdateTemplateRecipientsType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[RecipientUpdateTemplateRecipientsFieldMetaUnion],
        pydantic.Field(alias="fieldMeta"),
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientUpdateTemplateRecipientsRecipientResponseTypedDict(TypedDict):
    envelope_id: str
    role: RecipientUpdateTemplateRecipientsRoleResponse
    read_status: RecipientUpdateTemplateRecipientsReadStatus
    signing_status: RecipientUpdateTemplateRecipientsSigningStatus
    send_status: RecipientUpdateTemplateRecipientsSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[RecipientUpdateTemplateRecipientsAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    fields: List[RecipientUpdateTemplateRecipientsFieldTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientUpdateTemplateRecipientsRecipientResponse(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: RecipientUpdateTemplateRecipientsRoleResponse

    read_status: Annotated[
        RecipientUpdateTemplateRecipientsReadStatus, pydantic.Field(alias="readStatus")
    ]

    signing_status: Annotated[
        RecipientUpdateTemplateRecipientsSigningStatus,
        pydantic.Field(alias="signingStatus"),
    ]

    send_status: Annotated[
        RecipientUpdateTemplateRecipientsSendStatus, pydantic.Field(alias="sendStatus")
    ]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[RecipientUpdateTemplateRecipientsAuthOptions],
        pydantic.Field(alias="authOptions"),
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    fields: List[RecipientUpdateTemplateRecipientsField]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientUpdateTemplateRecipientsResponseTypedDict(TypedDict):
    r"""Successful response"""

    recipients: List[RecipientUpdateTemplateRecipientsRecipientResponseTypedDict]


class RecipientUpdateTemplateRecipientsResponse(BaseModel):
    r"""Successful response"""

    recipients: List[RecipientUpdateTemplateRecipientsRecipientResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class FieldDeleteTemplateFieldRequestTypedDict(TypedDict):
    field_id: float


class FieldDeleteTemplateFieldRequest(BaseModel):
    field_id: Annotated[float, pydantic.Field(alias="fieldId")]


class FieldDeleteTemplateFieldInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FieldDeleteTemplateFieldInternalServerErrorIssue(BaseModel):
    message: str


class FieldDeleteTemplateFieldInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldDeleteTemplateFieldInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FieldDeleteTemplateFieldInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FieldDeleteTemplateFieldInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldDeleteTemplateFieldInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldDeleteTemplateFieldForbiddenIssueTypedDict(TypedDict):
    message: str


class FieldDeleteTemplateFieldForbiddenIssue(BaseModel):
    message: str


class FieldDeleteTemplateFieldForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldDeleteTemplateFieldForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FieldDeleteTemplateFieldForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FieldDeleteTemplateFieldForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldDeleteTemplateFieldForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldDeleteTemplateFieldUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FieldDeleteTemplateFieldUnauthorizedIssue(BaseModel):
    message: str


class FieldDeleteTemplateFieldUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldDeleteTemplateFieldUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FieldDeleteTemplateFieldUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FieldDeleteTemplateFieldUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldDeleteTemplateFieldUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldDeleteTemplateFieldBadRequestIssueTypedDict(TypedDict):
    message: str


class FieldDeleteTemplateFieldBadRequestIssue(BaseModel):
    message: str


class FieldDeleteTemplateFieldBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldDeleteTemplateFieldBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FieldDeleteTemplateFieldBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FieldDeleteTemplateFieldBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldDeleteTemplateFieldBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldDeleteTemplateFieldResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class FieldDeleteTemplateFieldResponse(BaseModel):
    r"""Successful response"""

    success: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class EnvelopeRedistributeRequestTypedDict(TypedDict):
    envelope_id: str
    recipients: List[float]


class EnvelopeRedistributeRequest(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    recipients: List[float]


class EnvelopeRedistributeInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class EnvelopeRedistributeInternalServerErrorIssue(BaseModel):
    message: str


class EnvelopeRedistributeInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeRedistributeInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeRedistributeInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EnvelopeRedistributeInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeRedistributeInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeRedistributeForbiddenIssueTypedDict(TypedDict):
    message: str


class EnvelopeRedistributeForbiddenIssue(BaseModel):
    message: str


class EnvelopeRedistributeForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeRedistributeForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeRedistributeForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EnvelopeRedistributeForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeRedistributeForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeRedistributeUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EnvelopeRedistributeUnauthorizedIssue(BaseModel):
    message: str


class EnvelopeRedistributeUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeRedistributeUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeRedistributeUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EnvelopeRedistributeUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeRedistributeUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeRedistributeBadRequestIssueTypedDict(TypedDict):
    message: str


class EnvelopeRedistributeBadRequestIssue(BaseModel):
    message: str


class EnvelopeRedistributeBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeRedistributeBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeRedistributeBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EnvelopeRedistributeBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeRedistributeBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeRedistributeResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class EnvelopeRedistributeResponse(BaseModel):
    r"""Successful response"""

    success: bool
